==> nova_utils-0.0.1.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:nova_utils/nova_utils.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();
  }

  final TextEditingController _controller =
      new TextEditingController(text: "test");

  final TextEditingController _controllerValue =
      new TextEditingController(text: "默认的KeyValue");

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Column(
          children: <Widget>[
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                FlatButton(
                  child: Text('保存KEYChain'),
                  onPressed: () {
                    print("保存");
                    Map<String, String> params = {
                      _controller.value.text: _controllerValue.value.text,
                    };
                    NovaUtils.setKeyChanValue(params);
                  },
                ),
                FlatButton(
                  child: Text('获取KEYChain'),
                  onPressed: () {
                    List<String> paramsName = [_controller.value.text];
                    NovaUtils.getKeyChainValue(paramsName).then((value) {
                      var value2 = value[_controller.value.text];
                      _controllerValue.text = value2;
                      setState(() {});
                    });
                  },
                ),
              ],
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                Text("KeyChain"),
                Center(
                  child: TextFormField(
                    controller: _controller,
                  ),
                ),
                Text("KeyChainValue"),
                Center(
                  child: TextFormField(
                    controller: _controllerValue,
                  ),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}

==> nova_utils-0.0.8.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:nova_utils/nova_utils.dart';

void main() => runApp(MyApp());
class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Welcome to Flutter',
      debugShowCheckedModeBanner: false,
      home: Main(),
    );
  }
}
class Main extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<Main> {
  @override
  void initState() {
    super.initState();
  }

  final TextEditingController _controller =
      new TextEditingController(text: "test");

  final TextEditingController _controllerValue =
      new TextEditingController(text: "默认的KeyValue");

  void update() async{
    await  NovaUtils.checkUpdate(context);
  }
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Column(
          children: <Widget>[
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                FlatButton(
                  child: Text('保存KEYChain'),
                  onPressed: () {
                    print("保存");
                    Map<String, String> params = {
                      _controller.value.text: _controllerValue.value.text,
                    };
                    NovaUtils.setKeyChanValue(params);
                  },
                ),
                FlatButton(
                  child: Text('获取KEYChain'),
                  onPressed: () {
                    List<String> paramsName = [_controller.value.text];
                    NovaUtils.getKeyChainValue(paramsName).then((value) {
                      var value2 = value[_controller.value.text];
                      _controllerValue.text = value2;
                      setState(() {});
                    });
                  },
                ),
                FlatButton(
                  child: Text('提示更新'),
                  onPressed: () {
                    update();
                  },
                ),

              ],
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                Text("KeyChain"),
                Center(
                  child: TextFormField(
                    controller: _controller,
                  ),
                ),
                Text("KeyChainValue"),
                Center(
                  child: TextFormField(
                    controller: _controllerValue,
                  ),
                ),
              ],
            ),
          ],
        ),
    );
  }
}
